@@ -5,7 +5,7 @@
  * This code is under the following conditions:
  *
  * ---------------------------------------------------------------------
- * Copyright (c)2005-2014 Daniel Mealha Cabrita
+ * Copyright (c)2005-2021 Daniel Mealha Cabrita
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -98,10 +98,10 @@ extern in_addr_t *BindOutgoingExAddr;
 extern in_addr_t *BindOutgoing;
 extern int BindOutgoing_entries;
 
-extern int TOSFlagsDefault;
-extern int TOSFlagsDiff;
-extern char *TOSMarkAsDiffURL;
-extern int TOSMarkAsDiffSizeBT;
+extern int TOSFlagsDefault_cfg;
+extern int TOSFlagsDiff_cfg;
+extern char *TOSMarkAsDiffURL_cfg;
+extern int TOSMarkAsDiffSizeBT_cfg;
 extern int MaxActiveUserConnections;
 extern char *PIDFile;
 extern char *cli_PIDFile;
@@ -111,8 +111,8 @@ extern char *cli_RunAsUser;
 extern char *RunAsGroup;
 extern char *cli_RunAsGroup;
 
-extern const t_ut_urltable *tos_markasdiff_url;
-extern const t_ct_cttable *tos_maskasdiff_ct;
+extern const t_ut_urltable *tos_markasdiff_url_cfg;
+extern const t_ct_cttable *tos_maskasdiff_ct_cfg;
 
 extern const t_ut_urltable *urltable_noprocessing;
 extern const t_ut_urltable *urltable_replacedata;
