@@ -5,7 +5,7 @@
  * This code is under the following conditions:
  *
  * ---------------------------------------------------------------------
- * Copyright (c)2005-2014 Daniel Mealha Cabrita
+ * Copyright (c)2005-2021 Daniel Mealha Cabrita
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -905,7 +905,11 @@ int gif2bitmap(char *inbuf, int insize, raw_bitmap **out, long long int max_raw_
 	desc.size=insize;
 	desc.x.pos=0;
 
+#if GIFLIB_MAJOR >= 5
+	if ((GifFile = DGifOpen((void*)&desc, &gif_mem_input, NULL)) == NULL)
+#else
 	if ((GifFile = DGifOpen((void*)&desc, &gif_mem_input)) == NULL) 
+#endif
     		return( IMG_RET_ERR_UNKNOWN + IMG_RET_FLG_WHILE_DECOMP);//more possible reasons
 
 	bmp = new_raw_bitmap();
@@ -1083,7 +1087,11 @@ int gif2bitmap(char *inbuf, int insize, raw_bitmap **out, long long int max_raw_
 	}
 	bmp->pal_bpp = bmp->bpp;
 	
+#if GIFLIB_MAJOR >= 5
+	DGifCloseFile(GifFile, NULL);
+#else
 	DGifCloseFile(GifFile);
+#endif        
 	return IMG_RET_OK;
 }
 
@@ -1738,7 +1746,11 @@ static int bitmap2jp2 (raw_bitmap *bmp, float rate, char **outb, int *outl, cons
 		cmptparm->width = cwidth [cmptno];
 		cmptparm->height = cheight [cmptno];
 		cmptparm->prec = cbitlen [cmptno];
+#if GIFLIB_MAJOR >= 5
+		cmptparm->sgnd = 0;	// we only generate unsigned components
+#else
 		cmptparm->sgnd = false;	// we only generate unsigned components
+#endif
 
 		cshiftR [cmptno] = 8 - cbitlen [cmptno]; // calculate the resampling shift for this component
 	}
