@@ -5,7 +5,7 @@
  * This code is under the following conditions:
  *
  * ---------------------------------------------------------------------
- * Copyright (c)2005-2014 Daniel Mealha Cabrita
+ * Copyright (c)2005-2021 Daniel Mealha Cabrita
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -307,13 +307,13 @@ int main(int argc, char **argv, char *env[])
 					daemon_retcode = 9;
 					break;
 				case 2:
-					/* error while writting file */
-					error_log_puts (LOGMT_FATALERROR, LOGSS_DAEMON, "Error while writting PID file.");
+					/* error while writing file */
+					error_log_puts (LOGMT_FATALERROR, LOGSS_DAEMON, "Error while writing PID file.");
 					daemon_retcode = 9;
 					break;
 				default:
 					/* another error */
-					error_log_puts (LOGMT_FATALERROR, LOGSS_DAEMON, "Error while creating/writting PID file.");
+					error_log_puts (LOGMT_FATALERROR, LOGSS_DAEMON, "Error while creating/writing PID file.");
 					daemon_retcode = 9;
 					break;
 				}
@@ -633,7 +633,7 @@ void process_command_line_arguments (int argc, char **argv)
 				break;
 			case 'h':
 				printf ("Ziproxy " VERSION "\n"
-						"Copyright (c)2005-2014 Daniel Mealha Cabrita\n"
+						"Copyright (c)2005-2021 Daniel Mealha Cabrita\n"
 						"\n"
 
 						"This program is free software; you can redistribute it and/or modify\n"
