@@ -5,7 +5,7 @@
  * This code is under the following conditions:
  *
  * ---------------------------------------------------------------------
- * Copyright (c)2005-2014 Daniel Mealha Cabrita
+ * Copyright (c)2005-2021 Daniel Mealha Cabrita
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -98,8 +98,8 @@ int ziproxy (const char *client_addr, struct sockaddr_in *socket_host, SOCKET so
 	/* init TOS marking TOSMarking */
 	if (TOSMarking)
 		debug_log_puts ("TOS marking is enabled.");
-	if (tosmarking_init (TOSMarking, sock_child_out, TOSFlagsDefault, TOSFlagsDiff, tos_markasdiff_url, tos_maskasdiff_ct, TOSMarkAsDiffSizeBT))
-		debug_log_printf ("TOS: default traffic set to 0x%x\n", TOSFlagsDefault);
+	if (tosmarking_init (TOSMarking, sock_child_out, TOSFlagsDefault_cfg, TOSFlagsDiff_cfg, tos_markasdiff_url_cfg, tos_maskasdiff_ct_cfg, TOSMarkAsDiffSizeBT_cfg))
+		debug_log_printf ("TOS: default traffic set to 0x%x\n", TOSFlagsDefault_cfg);
 	
 	if(ConnTimeout){
 		/* catch timeouts */
